@@ -486,7 +486,7 @@ void DeKoratorConfig::setTheme()
 
 extern "C"
 {
-    KDE_EXPORT TQObject * allocate_config( TDEConfig * config, TQWidget * parent )
+    TDE_EXPORT TQObject * allocate_config( TDEConfig * config, TQWidget * parent )
     {
         return ( new DeKoratorConfig( config, parent ) );
     }
